==> realtime_trains_py-1.0.0b2.tar.gz: realtime_trains_py-1.0.0b2/SECURITY.md <==
# Security Policy

## Supported Versions

We release updates and patches regularly. Below are the versions of this project that are actively supported and maintained:

| Version | Supported          |
|---------|--------------------|
| 0.x.xax | :white_check_mark: |

If you are using an unsupported version, please upgrade to a supported version to receive the latest security updates.

## Reporting a Vulnerability

We take the security of realtime-trains-py seriously. If you discover a security vulnerability, please report it by following the steps below:

1. **Do not disclose the vulnerability publicly.** 
2. Email us at **[anonymous4401.ad@gmail.com](mailto:anonymous4401.ad@gmail.com)** with the details of the issue. Include the following information in your report:
   - A detailed description of the vulnerability.
   - Steps to reproduce the issue.
   - The potential impact or risk.

We aim to acknowledge your report within **3 days** and will provide a more detailed response within **10 working days**. 

After confirming the issue, we will:
- Collaborate with you to validate and address the vulnerability.
- Credit you for your discovery if desired and appropriate.

## Security Updates

We will post updates about resolved security vulnerabilities in the **[releases](https://github.com/anonymous44401/realtime-trains-py/releases)** section of this repository.

## Scope

This security policy applies to vulnerabilities in the source code and dependencies of this repository. It does not cover:
- General bugs that do not pose a security risk.
- Issues related to third-party services or tools.

Thank you for helping us keep realtime-trains-py secure!

==> realtime_trains_py-1.1.5b1.tar.gz: realtime_trains_py-1.1.5b1/SECURITY.md <==
# Security Policy

## Supported Versions

We release updates and patches regularly. Below are the versions of this project that are actively supported and maintained:

| Version | Supported          |
|---------|--------------------|
| 1.x.xbx | :white_check_mark: |
| 0.x.xax | :x:                |

If you are using an unsupported version, please upgrade to a supported version to receive the latest security updates.

## Reporting a Vulnerability

We take the security of the realtime-trains-py package seriously. If you discover a security vulnerability, please report it as soon as possible by emailing us at **[anonymous4401.ad@gmail.com](mailto:anonymous4401.ad@gmail.com)**.

Ensure you include the details of the issue. Include the following information in your report:
   - A detailed description of the vulnerability.
   - Steps to reproduce the issue.
      - How did you come across the vulnerability?
   - The potential impact or risk.

**Do not disclose the vulnerability publicly.** Sharing potential vulnerabilities could lead to exploitation or other adverse consequences.

We aim to acknowledge your report within **3 working days** and will provide a more detailed response within **10 working days**. 

After confirming the issue, we will:
- Collaborate with you to validate and address the vulnerability.
- Credit you for your discovery if desired and appropriate.

## Security Updates

We will post updates about resolved security vulnerabilities in the **[releases](https://github.com/anonymous44401/realtime-trains-py/releases)** section of this repository.

## Scope

This security policy applies to vulnerabilities in the source code and dependencies of this repository. It does not cover:
- General bugs that do not pose a security risk.
- Issues related to third-party services or tools.

Thank you for helping us keep realtime-trains-py secure!
